@@ -1,5 +1,6 @@
 import os
 
+
 def write_basic_yaml():
     return {
         "DIRECTORY": None,
@@ -7,17 +8,15 @@ def write_basic_yaml():
         "RMS": False,
     }
 
+
 def write_yaml():
-    return {
-        "DIRECTORY": "",
-        "WAVE LENGTHS": [None, None, None, None],
-        "RMS": False
-    }
+    return {"DIRECTORY": "", "WAVE LENGTHS": [None, None, None, None], "RMS": False}
+
 
 def write_acd_thermal_yaml():
     return {
         "DIRECTORY": "",
         "WAVE LENGTHS": [None, None, None, None],
         "RMS": False,
-        "MS Deadtime (Seconds)": 30
-    }
\ No newline at end of file
+        "MS Deadtime (Seconds)": 30,
+    }
